@@ -47,7 +47,7 @@ main (int argc, char **argv)
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 	textdomain (GETTEXT_PACKAGE);
 
-	g_set_prgname ("totem");
+	g_set_prgname (APPLICATION_ID);
 #if DEVELOPMENT_VERSION
 	g_set_application_name (_("Videos Preview"));
 #else
